      subroutine surface(v,rij)
        implicit none
!-----------------------------------------------------------------------
! This routine supplies the potential energy surface for the
! reactive scattering codes.
!
! On entering: The arrary rij contains the internuclear distances
!              in units of bohr (NOT mass scaled).
!
! On Exit:     The variable v is the value of the potential energy
!              surface in Hartree atomic units.
!
!
!-----------------------------------------------------------------------
      real*8 rij, v
      dimension rij(3)
      call surface1AP(v,rij)
      return
      end

