MODULE FileUnits_Module
   IMPLICIT NONE
   SAVE
   INTEGER, PARAMETER::msg_Unit      =  6
   INTEGER, PARAMETER::In_Unit       =  3
   INTEGER, PARAMETER::Out_Unit      =  4
   INTEGER, PARAMETER::frst_Unit     = 14
   INTEGER, PARAMETER::pmat_Unit     = 15
   INTEGER, PARAMETER::ovr_Unit      = 16
   INTEGER, PARAMETER::elvl_Unit     = 17
   INTEGER, PARAMETER::work_Unit     = 18
   INTEGER, PARAMETER::dwork_Unit    = 19
   INTEGER, PARAMETER::todo_Unit     = 20
   INTEGER, PARAMETER::phmat_Unit    = 21
   INTEGER, PARAMETER::fph_Unit      = 22
   INTEGER, PARAMETER::dmu_Unit      = 23
   INTEGER, PARAMETER::low_Unit      = 24
   INTEGER, PARAMETER::e_Unit        = 25
   INTEGER, PARAMETER::p_Unit        = 26
   INTEGER, PARAMETER::q_Unit        = 27
   INTEGER, PARAMETER::norm_Unit     = 28
   INTEGER, PARAMETER::intrp_Unit    = 29
   INTEGER, PARAMETER::bas_Unit      = 30
   INTEGER, PARAMETER::res_Unit      = 31
   INTEGER, PARAMETER::inho_Unit     = 32
   INTEGER, PARAMETER::tmutp_Unit    = 33
   INTEGER, PARAMETER::sflvl_Unit    = 34
   INTEGER, PARAMETER::jtot_Unit     = 35
   INTEGER, PARAMETER::lam_Unit      = 36
   INTEGER, PARAMETER::asym_Unit     = 37
   INTEGER, PARAMETER::cor_Unit      = 38
   INTEGER, PARAMETER::sbfrst_Unit   = 39
   INTEGER, PARAMETER::vec_Unit      = 40
   INTEGER, PARAMETER::vfrst_Unit    = 41
   INTEGER, PARAMETER::pfrst_Unit    = 42
   INTEGER, PARAMETER::weight_Unit   = 43
   INTEGER, PARAMETER::wfrst_Unit    = 44
   INTEGER, PARAMETER::sf33_Unit     = 45
   INTEGER, PARAMETER::sf34_Unit     = 46
   INTEGER, PARAMETER::phip_Unit     = 47
   INTEGER, PARAMETER::phid_Unit     = 48
   INTEGER, PARAMETER::efun_Unit     = 49
   INTEGER, PARAMETER::elm_Unit      = 50
   INTEGER, PARAMETER::nmode_Unit    = 51
   INTEGER, PARAMETER::progre_Unit   = 52
   INTEGER, PARAMETER::umat_Unit     = 53
   INTEGER, PARAMETER::sfunfbr_Unit  = 54
   INTEGER, PARAMETER::sflvl_Unit2   = 61
   INTEGER, PARAMETER::dvr7          = 67
   INTEGER, PARAMETER::dvr11         = 71
   INTEGER, PARAMETER::dvr12         = 72
   INTEGER, PARAMETER::dvr13         = 73
   INTEGER, PARAMETER::dvr14         = 74
   INTEGER, PARAMETER::dvr15         = 75
   INTEGER, PARAMETER::dvr16         = 76
   INTEGER, PARAMETER::dvr18         = 91
   INTEGER, PARAMETER::dvr23         = 77
   INTEGER, PARAMETER::dvr22         = 81
   INTEGER, PARAMETER::csv_unit      = 82
   INTEGER, PARAMETER::Vee_Unit      = 83
   INTEGER, PARAMETER::MTV_Unit      = 84
END MODULE FileUnits_Module
MODULE Numeric_Kinds_Module
   IMPLICIT NONE
   SAVE
   INTEGER, PARAMETER  :: sp=KIND(1.0)                   ! Single precsion
   INTEGER, PARAMETER  :: dp=SELECTED_REAL_KIND(14,300)  ! Double precsion
END MODULE Numeric_Kinds_Module

