      !-------------------------------------------------------------------
      ! subroutine: vli3
      !
      ! package   : Li3 Potential
      !
      ! Language  : Fortran 77
      !
      ! author    : F. Colavecchia (flavioc@lanl.gov)
      !
      ! date      : 05/12/02
      ! revision  :
      !
      ! purpose   : Li3 potential
      !
      ! input     :    r    -> (dim=3) interatomic distances in bohr.
      !
      ! output    :    v -> Li3  potential in a.u.
      !
      !-------------------------------------------------------------------!
      subroutine vli3_F(r,v)
      implicit none
      real*8 r(3),v,vli2,vli3_at
!
!     Compute the two body part
!     All this is in a.u.
!
      v = 0d0
      v = vli2(r(1))+vli2(r(2))+vli2(r(3))
      v = v + vli3_at(r)
      return 
      end 

